Polars Accessors
================

.. autoclass:: aliases.polars_accessor.PolarsSeriesAliasAccessor
    :members:

.. autoclass:: aliases.polars_accessor.PolarsExprAliasAccessor
    :members:

.. autoclass:: aliases.polars_accessor.PolarsDataFrameAliasAccessor
    :members:

.. autoclass:: aliases.polars_accessor.PolarsLazyFrameAliasAccessor
    :members:
